@@ -3,6 +3,7 @@ import pandas as pd
 import requests
 import datetime
 from datetime import date
+import yfinance as yf
 
 class TickerDataFetch:
 
@@ -20,21 +21,16 @@ class TickerDataFetch:
             ticker_date = item.split('.')[0].split()[1]
             self.namelist[ticker_name] = ticker_date
 
-    def fetch_historical_data(self, ticker, AV_key):
-        url = f'https://www.alphavantage.co/query?function=TIME_SERIES_DAILY&symbol={ticker}&outputsize=full&apikey={AV_key}'
-        r = requests.get(url)
-        data = r.json()
-        try:
-            historical_data = pd.DataFrame(data[list(data.keys())[1]]).transpose()
-        except:
-            print("Invalid ticker or Alpha Vantage Key")
-        historical_data.columns = ['O', 'H', 'L', 'C', 'V']
+    def fetch_historical_data(self, ticker):
+        ticker_data = yf.download(ticker, period='max')
         os.makedirs(self.output_folder, exist_ok=True)
         csv_path = os.path.join(self.output_folder, f"{ticker} {self.todays_date}.csv")
-        historical_data.to_csv(csv_path, index=True)
+        DataFrame = pd.DataFrame(ticker_data)
+        DataFrame.columns = ['Close','High','Low','Open','Volume']
+        DataFrame.to_csv(csv_path,index=True,header=True)
         print(f"Saved CSV to: {csv_path}")
 
-    def update_tickers (self,tickers,AV_key): 
+    def update_tickers (self,tickers): 
         self.folder_scan()
         for ticker in tickers:
             if ticker in self.namelist:
@@ -42,10 +38,10 @@ class TickerDataFetch:
                     print(ticker,"data found for",self.todays_date)
                 else:
                     os.remove(os.path.join(self.output_folder, f"{ticker} {self.namelist[ticker]}.csv"))
-                    self.fetch_historical_data(ticker,AV_key)
+                    self.fetch_historical_data(ticker)
                     print(ticker,"data found for",self.namelist[ticker],". Updating data for",self.todays_date)
             else:
-                self.fetch_historical_data(ticker,AV_key)
+                self.fetch_historical_data(ticker)
                 print(ticker,"data not found",{ticker},". Updating data for",self.todays_date)
         for ticker in self.namelist:
             if ticker in tickers:
@@ -60,7 +56,7 @@ class TickerDataFetch:
         self.folder_scan()
         for ticker in self.namelist:
             data = pd.read_csv(os.path.join(self.output_folder, f"{ticker} {self.namelist[ticker]}.csv"))
-            print(data.columns[0])
+            ticker_data.set_index('Date',inplace=True)
             ticker_data[ticker] = data
         return ticker_data
 
